/*
 * Demo.java
 * www.bouthier.net
 *
 * The MIT License :
 * -----------------
 * Copyright (c) 2001 Christophe Bouthier
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package hypertree.demo;

import hypertree.HyperTree;
import hypertree.HTView;

import java.io.*;
import java.awt.event.*;

//PDA
import javax.swing.JFrame;
//import java.awt.Frame;
//



/**
 * The Demo class implements a demo for HyperTree. It display an HyperTree
 * view of a demo tree.
 * The demo tree is build from a file tree, passed in parameter.
 * Demo could take an argument, the path from which 
 * start the representing of files.
 * If no arguments is given, the treemap start from the root.
 *
 * @author Christophe Bouthier [bouthier@loria.fr]
 * @version 1.0
 */
public class Demo {

    private static HTFileNode root      = null; // the root of the demo tree
    private static HyperTree  hypertree = null; // the hypertree builded


    /**
     * Display a demo HyperTree.
     */
    public static void main(String[] args) {
        String pathRoot = null;

        if (args.length > 0) {
            pathRoot = args[0];
        } else {
            pathRoot = ".";
        }

        File rootFile = new File(pathRoot);
        try {
            System.out.println("Starting the hyperbolic tree from " +
                                rootFile.getCanonicalPath());
        } catch (IOException e) {
            e.printStackTrace();
            return;
        }

        if (! rootFile.exists()) {
            System.out.println("Can't start hypertree : " + rootFile.getName() +
                               " does not exist.");
            return;
        }


        root = new HTFileNode(rootFile);
        if (root == null) {
            System.err.println("Error : can't start hypertree from " +
                                rootFile.getAbsolutePath());
            return;
        }

        hypertree = new HyperTree(root);
        HTView view = hypertree.getView();

        //PDA
        JFrame viewFrame = new JFrame(root.getName());
        viewFrame.setContentPane(view);
        //Frame viewFrame = new Frame(root.getName());
        //viewFrame.setSize(240, 280);
        //viewFrame.add(view);
        //PDA
		
		view.setLongNameMode(true);
		view.setProjType(-1);

        viewFrame.addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                System.exit(0);
            }
        });

        viewFrame.pack();
        viewFrame.setVisible(true);
    }

}

