/*
 * DemoNewick.java
 * www.bouthier.net
 *
 * The MIT License :
 * -----------------
 * Copyright (c) 2003 Christophe Bouthier
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package hypertree.demo;

import hypertree.HyperTree;
import hypertree.HTView;
import hypertree.HTNode;

import java.io.*;
import java.awt.event.*;

//PDA
import javax.swing.JFrame;
//import java.awt.Frame;
//PDA



/**
 * The DemoNewick class implements a demo for HyperTree that read the tree
 * to display in a file in the Newick tree format.
 * Demo take one argument, the path to the Newick file.
 *
 * @author Christophe Bouthier [bouthier@loria.fr]
 * @version 1.0
 */
public class DemoNewick {

    private static HTNode         root      = null; // root of the demo tree
    private static HyperTree      hypertree = null; // the hypertree builded
    private static HTNewickParser parser    = new HTNewickParser(); // parser


    /**
     * Display a demo HyperTree.
     */
    public static void main(String[] args) {
        String pathRoot = null;

        if (args.length > 0) {
            pathRoot = args[0];
        } else {
            System.err.println("DemoNewick needs the path to the Newick file");
            System.exit(0);
        }

        File file = new File(pathRoot);
        try {
            System.out.println("Searching for the file " +
                                file.getCanonicalPath());
        } catch (IOException e) {
            e.printStackTrace();
            return;
        }

        if (! file.exists()) {
            System.out.println("The file " + file.getName() +
                               " does not exist.");
            return;
        }


        root = parser.buildTree(file);
        if (root == null) {
            System.err.println("Error in parsing the Newick file " +
                                file.getAbsolutePath());
            return;
        }


        hypertree = new HyperTree(root);
        HTView view = hypertree.getView();

        //PDA
        JFrame viewFrame = new JFrame(root.getName());
        viewFrame.setContentPane(view);
        //Frame viewFrame = new Frame(root.getName());
        //viewFrame.setSize(240, 280);
        //viewFrame.add(view);
        //PDA

        viewFrame.addWindowListener(new WindowAdapter() {
            public void windowClosing(WindowEvent e) {
                System.exit(0);
            }
        });

        viewFrame.pack();
        viewFrame.setVisible(true);
    }

}

